/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "bet.h"

uint8_t pokerPlayerGetRemainingBetter(poker_t *poker) {
  uint8_t i, j;

  for(i = 0; i < poker->playerCount; i++) {
    j = (i + poker->playerBigBlind + 1) % poker->playerCount;
    if(pokerPlayerDoesNeedToBetThisRound(poker, j)) return j;
  }
  return 0xFF;
}


uint8_t pokerPlayerGetNextBetter(poker_t *poker, uint8_t current) {
  uint8_t i, j;

  for(i = 0; i < poker->playerCount; i++) {
    j = (i + current + 1) % poker->playerCount;
    if(pokerPlayerDoesNeedToBetThisRound(poker, j)) return j;
  }
  return 0xFF;
}

int32_t pokerPlayerGetCallBet(poker_t *poker, pokerplayer_t *player) {
  return pokerGetCallValue(poker) - player->currentBet;
}

uint8_t pokerPlayerGetRemainingBetterCount(poker_t *poker) {
  uint8_t i, count;
  count = 0;
  for(i = 0; i < poker->playerCount; i++) {
    if(!pokerPlayerDoesNeedToBetThisRound(poker, i)) continue;
    count++;
  }
  return count;
}

void pokerPlayerBetPot(
  poker_t *poker, pokerpot_t *pot, uint8_t playerIndex, int32_t chips
) {
  pokerplayer_t *player;
  player = poker->players + playerIndex;
  player->chips -= chips;
  player->currentBet += chips;
  pot->chips += chips;
  player->state |= POKER_PLAYER_STATE_HAS_BET_THIS_ROUND;
  pokerPotAddPlayer(pot, playerIndex);
}

void pokerPlayerBet(poker_t *poker, uint8_t playerIndex, int32_t chips) {
  pokerPlayerBetPot(
    poker, poker->pots + (poker->potCount - 1), playerIndex, chips
  );
}
